@@ -25,6 +25,8 @@
 #include <KUnitConversion/Converter>
 #include <KUnitConversion/UnitCategory>
 
+#include <cmath>
+
 #define CONVERSION_CHAR QLatin1Char( '>' )
 
 K_EXPORT_PLASMA_RUNNER(converterrunner, ConverterRunner)
@@ -227,6 +229,8 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
         }
     }
 
+    QList<Plasma::QueryMatch> matches;
+
     QLocale locale;
     KUnitConversion::Unit u1 = category.unit(unit1);
     foreach (const KUnitConversion::Unit& u, units) {
@@ -250,11 +254,14 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
 
         Plasma::QueryMatch match(this);
         match.setType(Plasma::QueryMatch::InformationalMatch);
-        match.setIcon(QIcon::fromTheme(QLatin1String( "edit-copy" )));
+        match.setIconName(QStringLiteral("edit-copy"));
         match.setText(QString(QLatin1String( "%1 (%2)" )).arg(v.toString()).arg(u.symbol()));
         match.setData(v.number());
-        context.addMatch(match);
+        match.setRelevance(1.0 - std::abs(std::log10(v.number())) / 50.0);
+        matches.append(match);
     }
+
+    context.addMatches(matches);
 }
 
 void ConverterRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
@@ -262,7 +269,7 @@ void ConverterRunner::run(const Plasma::RunnerContext &context, const Plasma::Qu
     Q_UNUSED(context)
     const QString data = match.data().toString();
     if (data.startsWith(QLatin1String("http://"))) {
-        QDesktopServices::openUrl(data);
+        QDesktopServices::openUrl(QUrl(data));
     } else {
         QGuiApplication::clipboard()->setText(data);
     }
